@@ -5,44 +5,95 @@ from datetime import datetime
 from requests.auth import HTTPBasicAuth
 from elasticsearch import Elasticsearch
 
-from automon.log.logger import Logging
-from automon.integrations.elasticsearch.config import ElasticsearchConfig
+from automon.log import Logging
+from .config import ElasticsearchConfig
 from automon.helpers.sanitation import Sanitation
 
 
-class ElasticsearchClient(ElasticsearchConfig):
-    def __init__(self, config: ElasticsearchConfig = None):
+class ElasticsearchClient(Elasticsearch):
+    def __init__(self, hosts: str = None,
+                 cloud_id: str = None,
+                 user: str = None,
+                 password: str = None,
+                 api_key: tuple = None,
+                 api_key_id: str = None,
+                 api_key_secret: str = None,
+                 config: ElasticsearchConfig = None):
+        """elasticsearch wrapper
+
+        :param hosts: str
+        :param cloud_id: str
+        :param user: str
+        :param password: str
+        :param api_key: base64 str
+        :param api_key_id: str
+        :param api_key_secret: str
+        :param config: class ElasticsearchConfig
+        """
+
         self._log = Logging(ElasticsearchClient.__name__, Logging.DEBUG)
 
-        self._config = config or ElasticsearchConfig()
-        self._client = Elasticsearch(hosts=self._config.es_hosts,
-                                     request_timeout=self._config.request_timeout,
-                                     http_auth=self._config.http_auth,
-                                     use_ssl=self._config.use_ssl,
-                                     verify_certs=self._config.verify_certs,
-                                     connection_class=self._config.connection_class)
+        self.config = config or ElasticsearchConfig(
+            hosts=hosts,
+            cloud_id=cloud_id,
+            user=user,
+            password=password,
+            api_key=api_key,
+            api_key_id=api_key_id,
+            api_key_secret=api_key_secret)
+
+        self.client = self._client()
+
         self.indices = []
         self.success = []
         self.errors = []
+        self.results = None
 
     def __repr__(self):
-        return f'{self._config}, {self._client}, indices: {self.indices}, errors: {self.errors}'
+        return f'{self.client}, indices: {self.indices}, errors: {self.errors}, {self.config}'
+
+    def _client(self):
+        try:
+            client = Elasticsearch(
+                hosts=self.config.ELASTICSEARCH_HOSTS,
+                cloud_id=self.config.ELASTICSEARCH_CLOUD_ID,
+                api_key=self.config.ELASTICSEARCH_API_KEY,
+                request_timeout=self.config.ELASTICSEARCH_REQUEST_TIMEOUT,
+                http_auth=self.config.http_auth,
+                use_ssl=self.config.use_ssl,
+                verify_certs=self.config.verify_certs,
+                connection_class=self.config.connection_class)
+            self._log.info(f'Connected to elasticsearch: {client}')
+            return client
+
+        except Exception as e:
+            self._log.error(f'Cannot connect to elasticsearch: {self.config.ELASTICSEARCH_HOSTS}, {e}')
+
+        return False
+
+    def isConnected(self):
+        return self.connected()
 
     def connected(self):
-        if self._config.es_hosts:
-            if self._client.ping():
-                return True
+        if self.client:
+            try:
+                if self.client.ping():
+                    return True
+            except Exception as e:
+                self._log.error(f'{e}', enable_traceback=False)
         return False
 
     def rest(self, url: str) -> requests:
         try:
-            if self._config.ELASTICSEARCH_USER and self._config.ELASTICSEARCH_PASSWORD:
-                r = requests.get(url, auth=HTTPBasicAuth(
-                    self._config.ELASTICSEARCH_USER,
-                    self._config.ELASTICSEARCH_PASSWORD
+            if self.config.ELASTICSEARCH_USER and self.config.ELASTICSEARCH_PASSWORD:
+                self.results = requests.get(url, auth=HTTPBasicAuth(
+                    self.config.ELASTICSEARCH_USER,
+                    self.config.ELASTICSEARCH_PASSWORD
                 ))
+                r = self.results
             else:
-                r = requests.get(url)
+                self.results = requests.get(url)
+                r = self.results
 
             self.success.append({'url': url, 'result': r})
             return r
@@ -56,7 +107,7 @@ class ElasticsearchClient(ElasticsearchConfig):
     def ping(self):
         if self.connected():
             try:
-                self._client.ping()
+                self.client.ping()
                 self._log.debug(f'Ping successful')
                 return True
             except Exception as e:
@@ -68,7 +119,9 @@ class ElasticsearchClient(ElasticsearchConfig):
     def delete_index(self, index: str, **kwargs):
         if self.connected():
             try:
-                r = self._client.indices.delete(index=index, ignore=[400, 404], **kwargs)
+                self.results = self.client.indices.delete(index=index, ignore=[400, 404], **kwargs)
+
+                r = self.results
                 self.success.append({'delete index': index, 'result': r})
                 self._log.debug(f'deleted index: {index}')
                 return True
@@ -81,7 +134,9 @@ class ElasticsearchClient(ElasticsearchConfig):
     def delete_document(self, index: str, id: str = None):
         if self.connected():
             try:
-                r = self._client.delete(index=index, id=id, ignore=[400, 404])
+                self.results = self.client.delete(index=index, id=id, ignore=[400, 404])
+
+                r = self.results
                 self.success.append({'index': index, 'id': id, 'result': r})
                 self._log.debug(f'deleted document: {index} {id}')
                 return True
@@ -92,6 +147,13 @@ class ElasticsearchClient(ElasticsearchConfig):
         return False
 
     def create_document(self, doc: dict, index: str = 'default', id: str = None):
+        """
+
+        :param doc:
+        :param index:
+        :param id:
+        :return: bool
+        """
         # doc = {
         #     'author': 'kimchy',
         #     'text': 'Elasticsearch: cool. bonsai cool.',
@@ -99,8 +161,10 @@ class ElasticsearchClient(ElasticsearchConfig):
         # }
 
         try:
-            r = self._client.index(index=index, body=doc, id=id)
-            self._client.indices.refresh(index=index)
+            self.results = self.client.index(index=index, body=doc, id=id)
+
+            r = self.results
+            self.client.indices.refresh(index=index)
             self.success.append({'doc': doc, 'index': index, 'id': id, 'result': r})
             self._log.debug(f'created document: {index} {id} {doc}')
             return True
@@ -115,7 +179,9 @@ class ElasticsearchClient(ElasticsearchConfig):
             search = {"query": {"match_all": {}}}
 
         try:
-            r = self._client.search(index=index, body=search)
+            self.results = self.client.search(index=index, body=search)
+
+            r = self.results
             self.success.append({'search': search, 'index': index, 'result': r})
             self._log.debug(f'search :{search} {index}, result {r}')
             return True
@@ -126,8 +192,9 @@ class ElasticsearchClient(ElasticsearchConfig):
 
     def search_summary(self, **kwargs):
 
-        res = self.search(kwargs)
+        self.results = self.search(kwargs)
 
+        res = self.results
         print(f"Got {res['hits']['total']['value']} Hits")
 
         for hit in res['hits']['hits']:
@@ -184,12 +251,15 @@ class ElasticsearchClient(ElasticsearchConfig):
     def search_indices(self, index_pattern):
         if self.connected() and index_pattern:
             try:
-                retrieved_indices = self._client.indices.get(index_pattern)
+                self.results = self.client.indices.get(index_pattern)
+
+                retrieved_indices = self.results
                 num_indices = len(retrieved_indices)
                 self._log.info(f'Search found {num_indices} indices')
                 self.success.append({'index pattern': index_pattern, 'result': retrieved_indices})
                 self._log.debug(f'search indices: {index_pattern}')
-                return retrieved_indices
+                return True
+
             except elasticsearch.exceptions.NotFoundError as e:
                 self._log.error(
                     f"You provided the index pattern '{index_pattern}', but returned no results")
@@ -200,22 +270,37 @@ class ElasticsearchClient(ElasticsearchConfig):
 
         return False
 
-    def get_indices(self):
+    def get_indices(self) -> bool:
         if self.connected():
             try:
-                retrieved_indices = self._client.indices.get('*')
-                self.indices.extend(retrieved_indices)
+                self.results = self.client.indices.get('*')
+
+                retrieved_indices = self.results
+                self.indices = retrieved_indices
                 self._log.info(f'Retrieved {len(retrieved_indices)} indices')
+
                 for i in retrieved_indices:
                     info = retrieved_indices.get(i)
                     date = int(info.get('settings').get('index').get('creation_date')) / 1000.0
                     date = datetime.fromtimestamp(date).strftime("%A, %B %d, %Y %I:%M:%S")
                     self._log.debug(f'Index: (created: {date})\t{i}')
+
                 self.success.append({'indices': retrieved_indices})
-                self._log.debug(f'get indices: {retrieved_indices}')
+                self._log.info(f'indices: {len(retrieved_indices)}')
                 return True
             except Exception as e:
                 self._log.error(f'Failed to get indices: {e}')
                 self.errors.append({'error': e})
 
         return False
+
+    def info(self) -> bool:
+
+        try:
+            self.results = self.client.info()
+            return True
+        except Exception as e:
+            self._log.error(f'Failed to get info:{e}')
+            self.errors.append({'error': e})
+
+        return False
