@@ -1,7 +1,7 @@
 import json
 # import requests
 
-from automon.log.logger import Logging
+from automon.log import Logging
 from automon.integrations.elasticsearch.client import ElasticsearchClient
 from automon.integrations.elasticsearch.config import ElasticsearchConfig
 
@@ -40,7 +40,7 @@ class ElasticsearchSnapshotMonitor:
         self._client = ElasticsearchClient(config=self._config)
         self.connected = self._client.connected()
 
-        self._endpoint = self._client._config.es_hosts
+        self._endpoint = self._client.config.ELASTICSEARCH_HOSTS
         self.repository = elasticsearch_repository
         self.snapshots_prefix = snapshots_prefix
 
@@ -170,7 +170,7 @@ class SnapshotError:
             self.status = error.get('status')
 
     def __eq__(self, other):
-        if not isinstance(other, SnapshotError):
-            self._log.error(f'{other} != SnapshotError')
-            return NotImplemented
-        return self.error == other.error
+        if isinstance(other, SnapshotError):
+            return self.error == other.error
+        self._log.warning(NotImplemented)
+        return NotImplemented
