@@ -1,4 +1,4 @@
-from automon.log.logger import Logging
+from automon.log import Logging
 
 log = Logging(name=__name__, level=Logging.DEBUG)
 
